@@ -5,12 +5,11 @@ use Carp 'croak';
 use DBI;
 use Mojo::mysql::Database;
 use Mojo::mysql::Migrations;
-use Mojo::mysql::PubSub;
 use Mojo::URL;
 use Scalar::Util 'weaken';
 use SQL::Abstract;
 
-has abstract => sub { SQL::Abstract->new };
+has abstract => sub { SQL::Abstract->new(quote_char => chr(96), name_sep => '.') };
 has auto_migrate    => 0;
 has database_class  => 'Mojo::mysql::Database';
 has dsn             => 'dbi:mysql:dbname=test';
@@ -25,13 +24,16 @@ has options => sub {
 };
 has [qw(password username)] => '';
 has pubsub => sub {
+  require Mojo::mysql::PubSub;
   my $pubsub = Mojo::mysql::PubSub->new(mysql => shift);
+  warn "Use of Mojo::mysql::PubSub is highly EXPERIMENTAL and should be considered an experiment"
+    unless $ENV{MOJO_PUBSUB_EXPERIMENTAL};
   weaken $pubsub->{mysql};
   return $pubsub;
 };
 
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 sub db {
   my $self = shift;
@@ -239,9 +241,6 @@ All cached database handles will be reset automatically if a new process has
 been forked, this allows multiple processes to share the same L<Mojo::mysql>
 object safely.
 
-Note that this whole distribution is EXPERIMENTAL and will change without
-warning!
-
 =head1 EVENTS
 
 L<Mojo::mysql> inherits all events from L<Mojo::EventEmitter> and can emit the
@@ -363,6 +362,8 @@ efficiently, by sharing a single database connection with many consumers.
   # Notify a channel
   $mysql->pubsub->notify(news => 'MySQL rocks!');
 
+Note that L<Mojo::mysql::PubSub> should be considered an experiment!
+
 =head2 username
 
   my $username = $mysql->username;
